@@ -1,6 +1,7 @@
 import logging
 import sys
 import traceback
+from pathlib import Path
 from typing import Optional
 
 import click
@@ -141,7 +142,7 @@ def cli(quiet: bool, verbose: bool) -> None:
 )
 @opt_network_retry_count
 def init_db(
-    database: str,
+    database: Path,
     user: Optional[str],
     password: Optional[str],
     oauth: bool,
@@ -199,7 +200,7 @@ def init_db(
 )
 @opt_network_retry_count
 def sync(
-    database: str,
+    database: Path,
     max_chunk_results: int,
     max_download_workers: int,
     download_cache_memory_limit: int,
@@ -232,21 +233,27 @@ def sync(
     "--no-export-date",
     is_flag=True,
     help=(
-        "Don't timestamp exported enex files."
+        "Don't timestamp exported ENEX files."
         " (e.g. to prevent backup chunking with zero changes)"
     ),
 )
+@click.option(
+    "--overwrite",
+    is_flag=True,
+    help="Overwrite existing ENEX files.",
+)
 @click.argument(
     "output_path",
     required=True,
     type=DIR_ONLY,
 )
 def export(
-    database: str,
+    database: Path,
     single_notes: bool,
     include_trash: bool,
     no_export_date: bool,
-    output_path: str,
+    overwrite: bool,
+    output_path: Path,
 ) -> None:
     """Export all notes from local database into ENEX files."""
 
@@ -255,6 +262,7 @@ def export(
         single_notes=single_notes,
         include_trash=include_trash,
         no_export_date=no_export_date,
+        overwrite=overwrite,
         output_path=output_path,
     )
 
@@ -269,7 +277,7 @@ click.password_option()
 )
 @opt_network_retry_count
 def reauth(
-    database: str,
+    database: Path,
     user: Optional[str],
     password: Optional[str],
     oauth: bool,
